@@ -245,7 +245,7 @@ class AzureAPI(BaseMicrosoftAPI):
         return postgresql_servers
 
     def servers_ids(self,resource_groups):
-        servers = self.list_mssql_server(resource_groups)
+        servers = self.list_mssql_servers(resource_groups)
         return [item['id'] for item in servers]
 
     def list_mariadb_databases(self):
@@ -314,7 +314,7 @@ class AzureAPI(BaseMicrosoftAPI):
             postgresql_databases += self.call_api(url)
         return postgresql_databases
 
-    def list_mssql_database(self, servers=None):
+    def list_mssql_databases(self, servers=None):
 
         if self.subscriptions is None:
             self.subscriptions = self.subscription_ids()
